Index: Source/core/inspector/InspectorMemoryAgent.cpp |
diff --git a/Source/core/inspector/InspectorMemoryAgent.cpp b/Source/core/inspector/InspectorMemoryAgent.cpp |
index 017c3626fe3a17417d5c8fe7267c9143d41b6654..6fa13c554019f7298db1e597db1328cb1fbabe3f 100644 |
--- a/Source/core/inspector/InspectorMemoryAgent.cpp |
+++ b/Source/core/inspector/InspectorMemoryAgent.cpp |
@@ -46,6 +46,7 @@ |
#include "core/page/Frame.h" |
#include "core/page/Page.h" |
#include "core/platform/MemoryUsageSupport.h" |
+#include "core/platform/Partitions.h" |
#include <wtf/ArrayBufferView.h> |
#include <wtf/HashSet.h> |
#include <wtf/MemoryInstrumentationArrayBufferView.h> |
@@ -74,7 +75,7 @@ public: |
m_sizesMap = sizesMap; |
// FIXME: We filter out Rendering type because the coverage is not good enough at the moment |
// and report RenderArena size instead. |
for (TypeNameToSizeMap::iterator i = m_sizesMap.begin(); i != m_sizesMap.end(); ++i) { |
if (i->key == PlatformMemoryTypes::Rendering) { |
m_sizesMap.remove(i); |
@@ -201,12 +202,14 @@ static void reportJSHeapInfo(WTF::MemoryInstrumentationClient& memoryInstrumenta |
memoryInstrumentationClient.countObjectSize(0, WebCoreMemoryTypes::JSHeapUnused, info.totalJSHeapSize - info.usedJSHeapSize); |
} |
-static void reportRenderTreeInfo(WTF::MemoryInstrumentationClient& memoryInstrumentationClient, Page* page) |
+static void reportRenderTreeInfo(WTF::MemoryInstrumentationClient& memoryInstrumentationClient, Page*) |
{ |
- ArenaSize arenaSize = page->renderTreeSize(); |
+ size_t renderTreeSize = 0; |
+#if ENABLE(PARTITION_ALLOC) |
+ renderTreeSize = partitionAllocGetUsedPagesSize(*Partitions::getRenderingPartition()); |
+#endif |
- memoryInstrumentationClient.countObjectSize(0, WebCoreMemoryTypes::RenderTreeUsed, arenaSize.treeSize); |
- memoryInstrumentationClient.countObjectSize(0, WebCoreMemoryTypes::RenderTreeUnused, arenaSize.allocated - arenaSize.treeSize); |
+ memoryInstrumentationClient.countObjectSize(0, WebCoreMemoryTypes::RenderTreeUsed, renderTreeSize); |
} |
namespace { |
@@ -74,7 +75,7 @@ public: |
m_sizesMap = sizesMap; |
// FIXME: We filter out Rendering type because the coverage is not good enough at the moment |
- // and report RenderArena size instead. |
+ // and report rendering partition size instead. |
for (TypeNameToSizeMap::iterator i = m_sizesMap.begin(); i != m_sizesMap.end(); ++i) { |
if (i->key == PlatformMemoryTypes::Rendering) { |